import { IsString } from 'class-validator';
import { NotAcceptableError, NotFoundError } from 'routing-controllers';

/**
 * Error to throw when a runner organisation couldn't be found.
 * Implemented this ways to work with the json-schema conversion for openapi.
 */
export class RunnerOrganisationNotFoundError extends NotFoundError {
	@IsString()
	name = "RunnerOrganisationNotFoundError"

	@IsString()
	message = "RunnerOrganisation not found!"
}

/**
 * Error to throw when two runner organisations' ids don't match.
 * Usually occurs when a user tries to change a runner's id.
 * Implemented this way to work with the json-schema conversion for openapi.
 */
export class RunnerOrganisationIdsNotMatchingError extends NotAcceptableError {
	@IsString()
	name = "RunnerOrganisationIdsNotMatchingError"

	@IsString()
	message = "The id's don't match!! \n And if you wanted to change a runner's id: This isn't allowed"
}

/**
 * Error to throw when a organisation still has runners associated.
 * Implemented this waysto work with the json-schema conversion for openapi.
 */
export class RunnerOrganisationHasRunnersError extends NotAcceptableError {
	@IsString()
	name = "RunnerOrganisationHasRunnersError"

	@IsString()
	message = "This organisation still has runners associated with it. \n If you want to delete this organisation with all it's runners and teams ass `?force` to your query."
}

/**
 * Error to throw when a organisation still has runners associated.
 * Implemented this waysto work with the json-schema conversion for openapi.
 */
export class RunnerOrganisationHasTeamsError extends NotAcceptableError {
	@IsString()
	name = "RunnerOrganisationHasTeamsError"

	@IsString()
	message = "This organisation still has teams associated with it. \n If you want to delete this organisation with all it's runners and teams ass `?force` to your query."
}

/**
 * Error to throw, when a provided runnerOrganisation doesn't belong to the accepted types.
 */
export class RunnerOrganisationWrongTypeError extends NotAcceptableError {
	@IsString()
	name = "RunnerOrganisationWrongTypeError"

	@IsString()
	message = "The runner organisation must be an existing organisation's id. \n You provided a object of another type."
}
