import { IsInt } from 'class-validator';
import { getConnectionManager } from 'typeorm';
import { RunnerGroupNotFoundError } from '../../errors/RunnerGroupErrors';
import { RunnerOrganisationWrongTypeError } from '../../errors/RunnerOrganisationErrors';
import { RunnerTeamNeedsParentError } from '../../errors/RunnerTeamErrors';
import { Runner } from '../entities/Runner';
import { RunnerGroup } from '../entities/RunnerGroup';
import { CreateParticipant } from './CreateParticipant';

export class CreateRunner extends CreateParticipant {

    /**
     * The new runner's group's id.
     */
    @IsInt()
    group: number;

    /**
     * Creates a Runner entity from this.
     */
    public async toRunner(): Promise<Runner> {
        let newRunner: Runner = new Runner();

        newRunner.firstname = this.firstname;
        newRunner.middlename = this.middlename;
        newRunner.lastname = this.lastname;
        newRunner.phone = this.phone;
        newRunner.email = this.email;
        newRunner.group = await this.getGroup();
        newRunner.address = await this.getAddress();

        return newRunner;
    }

    /**
     * Manages all the different ways a group can be provided.
     */
    public async getGroup(): Promise<RunnerGroup> {
        if (this.group === undefined) {
            throw new RunnerTeamNeedsParentError();
        }
        if (!isNaN(this.group)) {
            let group = await getConnectionManager().get().getRepository(RunnerGroup).findOne({ id: this.group });
            if (!group) { throw new RunnerGroupNotFoundError; }
            return group;
        }

        throw new RunnerOrganisationWrongTypeError;
    }
}