import {
  IsEmail,
  IsInt,
  IsNotEmpty,
  IsOptional,
  IsPhoneNumber,

  IsString
} from "class-validator";
import { Column, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn } from "typeorm";
import { config } from '../../config';
import { Address } from "./Address";
import { RunnerGroup } from "./RunnerGroup";

/**
 * Defines a group's contact.
*/
@Entity()
export class GroupContact {
  /**
 * Autogenerated unique id (primary key).
 */
  @PrimaryGeneratedColumn()
  @IsInt()
  id: number;

  /**
   * The contact's first name.
   */
  @Column()
  @IsNotEmpty()
  @IsString()
  firstname: string;

  /**
   * The contact's middle name.
   * Optional
   */
  @Column({ nullable: true })
  @IsOptional()
  @IsString()
  middlename?: string;

  /**
   * The contact's last name.
   */
  @Column()
  @IsNotEmpty()
  @IsString()
  lastname: string;

  /**
   * The contact's address.
   * Optional
   */
  @IsOptional()
  @ManyToOne(() => Address, address => address.participants, { nullable: true })
  address?: Address;

  /**
   * The contact's phone number.
   * Optional
   */
  @Column({ nullable: true })
  @IsOptional()
  @IsPhoneNumber(config.phone_validation_countrycode)
  phone?: string;

  /**
   * The contact's email address.
   * Optional
   */
  @Column({ nullable: true })
  @IsOptional()
  @IsEmail()
  email?: string;

  /**
    * Used to link contacts to groups.
    */
  @OneToMany(() => RunnerGroup, group => group.contact, { nullable: true })
  groups: RunnerGroup[];
}