import { IsInt, IsNotEmpty } from "class-validator";
import { ChildEntity, ManyToOne, OneToMany } from "typeorm";
import { DistanceDonation } from "./DistanceDonation";
import { Participant } from "./Participant";
import { RunnerCard } from "./RunnerCard";
import { RunnerGroup } from "./RunnerGroup";
import { Scan } from "./Scan";

/**
 * Defines a runner.
*/
@ChildEntity()
export class Runner extends Participant {
  /**
   * The runner's associated group.
   */
  @IsNotEmpty()
  @ManyToOne(() => RunnerGroup, group => group.runners, { nullable: false })
  group: RunnerGroup;

  /**
   * Used to link runners to donations.
   */
  @OneToMany(() => DistanceDonation, distanceDonation => distanceDonation.runner, { nullable: true })
  distanceDonations: DistanceDonation[];

  /**
   * Used to link runners to cards.
   */
  @OneToMany(() => RunnerCard, card => card.runner, { nullable: true })
  cards: RunnerCard[];

  /**
   * Used to link runners to a scans
   */
  @OneToMany(() => Scan, scan => scan.runner, { nullable: true })
  scans: Scan[];

  /**
   * Returns all valid scans associated with this runner.
   */
  public get validScans(): Scan[] {
    return this.scans.filter(scan => { scan.valid === true });
  }

  /**
   * Returns the total distance ran by this runner.
  */
  @IsInt()
  public get distance(): number {
    return this.validScans.reduce((sum, current) => sum + current.distance, 0);
  }
}