import {
    IsInt,
    IsObject
} from "class-validator";
import { Runner } from '../entities/Runner';
import { RunnerGroup } from '../entities/RunnerGroup';
import { ResponseParticipant } from './ResponseParticipant';

/**
 * Defines RunnerTeam's response class.
*/
export class ResponseRunner extends ResponseParticipant {

    /**
     * The runner's currently ran distance in meters.
     * Optional.
     */
    @IsInt()
    distance: number;

    /**
     * The runner's group.
     */
    @IsObject()
    group: RunnerGroup;

    public constructor(runner: Runner) {
        super(runner);
        this.distance = runner.scans.filter(scan => { scan.valid === true }).reduce((sum, current) => sum + current.distance, 0);
        this.group = runner.group;
    }
}
