import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

// ---------------
describe('adding + deletion (non-existant)', () => {
    it('delete', async () => {
        const res2 = await axios.delete(base + '/api/organisations/0', { validateStatus: undefined });
        expect(res2.status).toEqual(204);
    });
});
// ---------------
describe('adding + deletion (successfull)', () => {
    let added_org_id
    let added_org
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        });
        added_org = res1.data
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('delete', async () => {
        const res2 = await axios.delete(base + '/api/organisations/' + added_org_id);
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
        let added_org2 = res2.data
        added_org_id = added_org2.id;
        delete added_org2.id
        expect(added_org2).toEqual({
            "name": "test123",
            "contact": null,
            "address": null,
            "teams": []
        });
    });
    it('check if org really was deleted', async () => {
        const res3 = await axios.get(base + '/api/organisations/' + added_org_id, { validateStatus: undefined });
        expect(res3.status).toEqual(404);
        expect(res3.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('adding + deletion with teams still existing (without force)', () => {
    let added_org;
    let added_org_id;
    let added_team;
    let added_team_id
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        });
        added_org = res1.data;
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new team with a valid org should return 200', async () => {
        const res2 = await axios.post(base + '/api/teams', {
            "name": "test123",
            "parentGroup": added_org_id
        });
        added_team = res2.data;
        added_team_id = added_team.id;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('delete org - this should fail with a 406', async () => {
        const res2 = await axios.delete(base + '/api/organisations/' + added_org_id, { validateStatus: undefined });
        expect(res2.status).toEqual(406);
        expect(res2.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('adding + deletion with teams still existing (with force)', () => {
    let added_org;
    let added_org_id;
    let added_team;
    let added_team_id
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        });
        added_org = res1.data;
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new team with a valid org should return 200', async () => {
        const res2 = await axios.post(base + '/api/teams', {
            "name": "test123",
            "parentGroup": added_org_id
        });
        added_team = res2.data;
        added_team_id = added_team.id;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('delete', async () => {
        const res2 = await axios.delete(base + '/api/organisations/' + added_org_id + '?force=true');
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
        let added_org2 = res2.data
        added_org_id = added_org2.id;
        delete added_org2.id;
        delete added_org2.teams;
        expect(added_org2).toEqual({
            "name": "test123",
            "contact": null,
            "address": null
        });
    });
    it('check if org really was deleted', async () => {
        const res3 = await axios.get(base + '/api/organisations/' + added_org_id, { validateStatus: undefined });
        expect(res3.status).toEqual(404);
        expect(res3.headers['content-type']).toContain("application/json")
    });
});