import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

describe('GET /api/runners', () => {
    it('basic get should return 200', async () => {
        const res = await axios.get(base + '/api/runners');
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/runners/0', () => {
    it('basic get should return 404', async () => {
        const res = await axios.get(base + '/api/runners/0', { validateStatus: undefined });
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('POST /api/runners with errors', () => {
    it('creating a new runner without any parameters should return 400', async () => {
        const res1 = await axios.post(base + '/api/runners', null, { validateStatus: undefined });
        expect(res1.status).toEqual(400);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner without a group should return 400', async () => {
        const res2 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "middlename": "middle",
            "lastname": "last"
        }, { validateStatus: undefined });
        expect(res2.status).toEqual(400);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner with a invalid valid group should return 404', async () => {
        const res2 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "middlename": "middle",
            "lastname": "last",
            "group": 0
        }, { validateStatus: undefined });
        expect(res2.status).toEqual(404);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner without a invalid phone number should return 400', async () => {
        const res2 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "middlename": "middle",
            "lastname": "last",
            "phone": "123"
        }, { validateStatus: undefined });
        expect(res2.status).toEqual(400);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner without a invalid mail address should return 400', async () => {
        const res2 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "middlename": "middle",
            "lastname": "last",
            "email ": "123"
        }, { validateStatus: undefined });
        expect(res2.status).toEqual(400);
        expect(res2.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('POST /api/runners working', () => {
    let added_org_id;
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        });
        let added_org = res1.data
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner with only needed params should return 200', async () => {
        const res2 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "lastname": "last",
            "group": added_org_id
        }, { validateStatus: undefined });
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner with all non-relationship optional params should return 200', async () => {
        const res3 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "middlename": "middle",
            "lastname": "last",
            "email": "test@example.com",
            "phone": "+4909123123456789",
            "group": added_org_id
        }, { validateStatus: undefined });
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
    });
});