import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

describe('GET /api/runners', () => {
    it('basic get should return 200', async () => {
        const res = await axios.get(base + '/api/runners');
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/runners/0', () => {
    it('basic get should return 404', async () => {
        const res = await axios.get(base + '/api/runners/0', { validateStatus: undefined });
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/runners after adding', () => {
    let added_org_id;
    let added_runner;
    it('creating a new org with just a name should return 200', async () => {
        const res1 = await axios.post(base + '/api/organisations', {
            "name": "test123"
        });
        let added_org = res1.data
        added_org_id = added_org.id;
        expect(res1.status).toEqual(200);
        expect(res1.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner with only needed params should return 200', async () => {
        const res2 = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "lastname": "last",
            "group": added_org_id
        }, { validateStatus: undefined });
        added_runner = res2.data;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('explicit get should return 200', async () => {
        const res3 = await axios.get(base + '/api/runners/' + added_runner.id, { validateStatus: undefined });
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
        let gotten_runner = res3.data
        expect(gotten_runner).toEqual(added_runner);
    });
    it('get from all runners should return 200', async () => {
        const res4 = await axios.get(base + '/api/runners/', { validateStatus: undefined });
        expect(res4.status).toEqual(200);
        expect(res4.headers['content-type']).toContain("application/json")
        let gotten_runners = res4.data
        expect(gotten_runners).toContainEqual(added_runner);
    });
});